# better-cookiecutter

[![PyPI](https://img.shields.io/pypi/v/better-cookiecutter)](https://pypi.org/project/better-cookiecutter/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/better-cookiecutter)](https://pypi.org/project/better-cookiecutter/)
[![PyPI License](https://img.shields.io/pypi/l/better-cookiecutter)](https://pypi.org/project/better-cookiecutter/)
[![Code Style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black/)

Use cookiecutter with yaml files, or even with python files.

